---
title: <span class="badge builder"></span> UniqueCount
---
# <span class="badge builder"></span> UniqueCount

## Constructor

```python
UniqueCount()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> elasticsearch.UniqueCount
```

### <span class="badge object-method"></span> field

```python
def field(field: str) -> typing.Self
```

### <span class="badge object-method"></span> hide

```python
def hide(hide: bool) -> typing.Self
```

### <span class="badge object-method"></span> id_val

```python
def id_val(id_val: str) -> typing.Self
```

### <span class="badge object-method"></span> settings

```python
def settings(settings: cogbuilder.Builder[elasticsearch.ElasticsearchUniqueCountSettings]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [UniqueCount](./object-UniqueCount.md)
